import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { NavController } from '@ionic/angular';
import { addIcons } from 'ionicons';
import { checkmarkOutline } from 'ionicons/icons';

@Component({
  selector: 'app-edit',
  templateUrl: './edit.page.html',
  styleUrls: ['./edit.page.scss'],
  standalone:false,
})
export class EditPage implements OnInit {
  diaryId: string | null = null;
  diary = {
    date: new Date().toISOString(),
    weekday: this.getWeekday(new Date()),
    time: this.getCurrentTime(),
    content: '',
    weather: '晴',
    mood: '😊'
  };

  constructor(
    private route: ActivatedRoute,
    private navCtrl: NavController,
    private router: Router
  ) {
    addIcons({ checkmarkOutline });
  }

  ngOnInit() {
    this.diaryId = this.route.snapshot.paramMap.get('id');
    
    // 如果是编辑模式，加载现有日记数据
    if (this.diaryId) {
      const state = this.router.getCurrentNavigation()?.extras.state;
      if (state) {
        this.diary = {
          ...this.diary,
          ...state
        };
      }
    }
  }

  // 获取当前星期
  private getWeekday(date: Date): string {
    const weekdays = ['周日', '周一', '周二', '周三', '周四', '周五', '周六'];
    return weekdays[date.getDay()];
  }

  // 获取当前时间 (HH:mm)
  private getCurrentTime(): string {
    const now = new Date();
    const hours = now.getHours().toString().padStart(2, '0');
    const minutes = now.getMinutes().toString().padStart(2, '0');
    return `${hours}:${minutes}`;
  }

  saveDiary() {
    console.log('保存日记:', this.diary);
    
    // 这里添加保存到数据库的逻辑
    
    // 返回上一页
    this.navCtrl.back();
  }
}